@@ -21,9 +21,12 @@ class Photo:
             time_interval (float): The interval between photos in seconds, disable with -1.0
             distance_interval (float): The interval between photos in meters, disable with -1.0
 
+        Raises:
+            ValueError: If time_interval cannot be float or distance_interval cannot be float
+
         """
-        self.time_interval = time_interval
-        self.distance_interval = distance_interval
+        self.time_interval = float(time_interval)
+        self.distance_interval = float(distance_interval)
 
     def set_time_interval(self, interval: float):
         """
@@ -32,9 +35,12 @@ class Photo:
         Args:
             interval (float): The interval between photos in seconds, disable with -1.0
 
+        Raises:
+            ValueError: If interval cannot be float
+
         """
-        self.time_interval = interval
-        self.distance_interval = 0
+        self.time_interval = float(interval)
+        self.distance_interval = float(0)
 
     def set_distance_interval(self, interval: float):
         """
@@ -43,6 +49,9 @@ class Photo:
         Args:
             interval (float): The interval between photos in seconds, disable with -1.0
 
+        Raises:
+            ValueError: If interval cannot be float
+
         """
-        self.distance_interval = interval
-        self.time_interval = 0
+        self.distance_interval = float(interval)
+        self.time_interval = float(0)
